@@ -36,11 +36,13 @@ item_event (GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 				y = item_y;
 
 				fleur = gdk_cursor_new (GDK_FLEUR);
+#if 0
 				gnome_canvas_item_grab (item,
 							GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
 							fleur,
 							event->button.time);
-				gdk_cursor_destroy (fleur);
+#endif
+				gdk_cursor_unref (fleur);
 				dragging = TRUE;
 			}
 			break;
@@ -234,7 +236,7 @@ setup_rectangles (GnomeCanvasGroup *root)
 						   "outline_color", "black",
 						   "width_units", 4.0,
 						   NULL));
-		gdk_bitmap_unref (stipple);
+		g_object_unref (stipple);
 	}
 
 	setup_item (gnome_canvas_item_new (root,
@@ -297,7 +299,7 @@ setup_ellipses (GnomeCanvasGroup *root)
 						   "outline_color", "black",
 						   "width_pixels", 0,
 						   NULL));
-		gdk_bitmap_unref (stipple);
+		g_object_unref (stipple);
 	}
 }
 
@@ -353,7 +355,7 @@ setup_texts (GnomeCanvasGroup *root)
 				       "fill_color", "blue",
 				       "fill_stipple", stipple,
 				       NULL);
-		gdk_bitmap_unref (stipple);
+		g_object_unref (stipple);
 	}
 
 	gnome_canvas_item_new (make_anchor (root, 470.0, 75.0),
@@ -401,7 +403,7 @@ plant_flower (GnomeCanvasGroup *root, double x, double y, GtkAnchorType anchor,
 /*  					       "anchor", anchor, */
 					       NULL);
 		setup_item (image);
-		gdk_pixbuf_unref(im);
+		g_object_unref (im);
 	}
 }
 
@@ -423,7 +425,7 @@ setup_images (GnomeCanvasGroup *root, int aa)
 /*  					       "anchor", GTK_ANCHOR_CENTER, */
 					       NULL);
 		setup_item (image);
-		gdk_pixbuf_unref(im);
+		g_object_unref (im);
 	} else
 		g_warning ("Could not find the toroid.png sample file");
 
@@ -534,7 +536,7 @@ make_hilbert (GnomeCanvasGroup *root)
 						   "cap_style", GDK_CAP_PROJECTING,
 						   "join_style", GDK_JOIN_MITER,
 						   NULL));
-		gdk_bitmap_unref (stipple);
+		g_object_unref (stipple);
 	}
 
 	gnome_canvas_points_free (points);
@@ -656,7 +658,7 @@ setup_polygons (GnomeCanvasGroup *root)
 						   "fill_stipple", stipple,
 						   "outline_color", "black",
 						   NULL));
-		gdk_bitmap_unref (stipple);
+		g_object_unref (stipple);
 	}
 	gnome_canvas_points_free (points);
 
@@ -767,7 +769,7 @@ create_canvas_primitives (gint aa)
 
 	/* Create the canvas */
 
-	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
+	gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 	if (aa)
 	  canvas = gnome_canvas_new_aa ();
 	else
@@ -812,7 +814,7 @@ create_canvas_primitives (gint aa)
 	gtk_box_pack_start (GTK_BOX (hbox), w, FALSE, FALSE, 0);
 	gtk_widget_show (w);
 
-	adj = GTK_ADJUSTMENT (gtk_adjustment_new (1.00, 0.05, 5.00, 0.05, 0.50, 0.50));
+	adj = GTK_ADJUSTMENT (gtk_adjustment_new (1.00, 0.05, 5.00, 0.05, 0.50, 0));
 	g_signal_connect (adj, "value_changed",
 			  G_CALLBACK (zoom_changed),
 			  canvas);
