@@ -50,13 +50,13 @@ static void   gnome_canvas_bpath_update      (GnomeCanvasItem *item, double *aff
 
 static GnomeCanvasShapeClass *parent_class;
 
-GtkType
+GType
 gnome_canvas_bpath_get_type (void)
 {
 	static GType bpath_type;
 
 	if (!bpath_type) {
-		static const GTypeInfo object_info = {
+		const GTypeInfo object_info = {
 			sizeof (GnomeCanvasBpathClass),
 			(GBaseInitFunc) NULL,
 			(GBaseFinalizeFunc) NULL,
